@@ -1,18 +1,19 @@
-# -*- coding: utf-8 -*-
+# Copyright (C) 2020 Dremio
+#
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
+#
+# http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
 """Makes sure the expression building functions work properly."""
-#  Copyright (C) 2020 Dremio
-#
-#  Licensed under the Apache License, Version 2.0 (the "License");
-#  you may not use this file except in compliance with the License.
-#  You may obtain a copy of the License at
-#
-#  http://www.apache.org/licenses/LICENSE-2.0
-#
-#  Unless required by applicable law or agreed to in writing, software
-#  distributed under the License is distributed on an "AS IS" BASIS,
-#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-#  See the License for the specific language governing permissions and
-#  limitations under the License.
+
+from typing import List
 
 from assertpy import assert_that
 
@@ -32,8 +33,8 @@ def test_building_empty_filter() -> None:
 
 def test_building_filter_for_commit_log() -> None:
     """Makes sure the filter building function for the commit log produces what we expect."""
-    authors = []
-    committers = []
+    authors: List[str] = []
+    committers: List[str] = []
     since = None
     until = None
     query_expr = ""
